@@ -14,35 +14,33 @@ def body_to_json(messageArgs):
         messageArgs["body"] = messageArgs["body"].decode()
         messageArgs["body"] = json.loads(messageArgs["body"])
 
-    except json.decoder.JSONDecodeError as e:
+    except json.decoder.JSONDecodeError:
         body = messageArgs["body"]
         raise Exception(f"({body}) is not a valid JSON")
 
 
-def create_handler(
-    handler,
-    on_success,
-    on_error,
-    after_all,
-):
+def create_handler(handler):
     async def message_handler(message: IncomingMessage):
+        async def ack():
+            await message.ack()
+        async def reject():
+            await message.nack(requeue=False)
+        async def requeue():
+            await message.nack(requeue=True)
         messageArgs = {
             "body": message.body,
             "routing_key": message.routing_key,
             "exchange": message.exchange,
+            "ack": ack,
+            "reject": reject,
+            "requeue": requeue,
         }
         try:
             body_to_json(messageArgs)
-            await await_if_async(handler, messageArgs)
-            await await_if_async(on_success, messageArgs)
-            await message.ack()
-
-        except Exception as error:
-            await await_if_async(on_error, messageArgs, error)
+        except Exception as err:
             await message.nack(requeue=False)
-
-        finally:
-            await await_if_async(after_all, messageArgs)
+            raise err
+        await await_if_async(handler, messageArgs)
 
     return message_handler
 
@@ -51,23 +49,11 @@ class ConsumeController:
     def __init__(self, channel_controller: ChannelController):
         self.channel_controller = channel_controller
 
-    async def consume(
-        self,
-        queue_name,
-        handler,
-        on_success=None,
-        on_error=None,
-        after_all=None,
-    ):
+    async def consume(self, queue_name, handler):
         channel = await self.channel_controller.get_channel()
         queue = await channel.get_queue(queue_name)
-        
+
         print(f"Consuming: {queue_name}")
-        message_handler = create_handler(
-            handler,
-            on_success,
-            on_error,
-            after_all,
-        )
+        message_handler = create_handler(handler)
 
         return await queue.consume(message_handler)
