@@ -1,6 +1,6 @@
 import json
 from aio_pika import Message
-from channel_controller import ChannelController
+from eon_rabbit_client.channel_controller import ChannelController
 
 
 class PublishController():
