@@ -1,5 +1,5 @@
 import asyncio
-from channel_controller import ChannelController
+from eon_rabbit_client.channel_controller import ChannelController
 
 
 class QueueController:
@@ -9,7 +9,7 @@ class QueueController:
 
     async def assert_queue(self, queue_name):
         channel = await self._channel_controller.get_channel()
-        await channel.declare_queue(queue_name)
+        await channel.declare_queue(queue_name, durable=True)
         
     async def bind_queue(self, queue_name, exchange, bindingKeys):
         channel = await self._channel_controller.get_channel()
